@@ -6,8 +6,11 @@ import io
 import json
 import zipfile
 
+from deprecation import deprecated
 from PIL import Image
 
+jsonLoadsFromArchive = lambda x: json.loads(x.read_text(encoding="utf-8"))
+
 
 class LSRImage:
 	"""LSRImage contains data on the overall size, the layers and the name of the lsr image."""
@@ -26,8 +29,7 @@ class LSRImage:
 
 
 class LSRLayer:
-	"""LSRLayer contains data on the layer such as the list of images, the name...
-
+	"""LSRLayer contains data on the layer such as the list of images, the name,
 	the size and the centre offset.
 	"""
 
@@ -49,7 +51,7 @@ class LSRLayer:
 		# return 0, 0
 
 	def flatten(self) -> Image.Image:
-		"""Faltten all of the layers."""
+		"""Flatten all of the layers."""
 		return flattenAll(self.images, self.size)
 
 
@@ -91,16 +93,17 @@ def read(filename: str) -> LSRImage:
 	"""
 	lsrImage = None
 	with zipfile.ZipFile(filename, "r") as zipref:
-		contents = json.load(zipref.open("Contents.json"))
+		zippath = zipfile.Path(zipref)
+		contents = jsonLoadsFromArchive(zippath / "Contents.json")
 		layers = contents["layers"]
 		lsrLayers = []
 		for layer in layers:
 			lsrImageData = []
-			layerContents = json.load(zipref.open(layer["filename"] + "/Contents.json"))[
-				"properties"
-			]
-			layerImagesList = json.load(
-				zipref.open(layer["filename"] + "/Content.imageset/Contents.json")
+			layerContents = jsonLoadsFromArchive(
+				zippath / layer["filename"] / "Contents.json",
+			)["properties"]
+			layerImagesList = jsonLoadsFromArchive(
+				zippath / layer["filename"] / "Content.imageset/Contents.json",
 			)["images"]
 			for image in layerImagesList:
 				with zipref.open(
@@ -110,8 +113,8 @@ def read(filename: str) -> LSRImage:
 						LSRImageData(
 							Image.open(layerImage).convert("RGBA"),
 							image["filename"].replace(".png", ""),
-							image["scale"],
-							image["idiom"],
+							image.get("scale", "1x"),
+							image.get("idiom", "universal"),
 						)
 					)
 			lsrLayers.append(
@@ -201,16 +204,16 @@ def flattenTwoLayers(
 	Args:
 		layer (LSRImageData): lsrimagedata
 		imageDimensions (tuple[int, int]): a tuple of the image dimensions
-		flattenedSoFar (Image.Image, optional): Raster of what has already been
+		flattenedSoFar (Image.Image, optional): Render of what has already been
 		flattened. Defaults to None.
 
 	Returns:
 		Image.Image: Flattened image
 	"""
-	foregroundRaster = rasterImageOffset(layer.scaledImage(), imageDimensions, layer.offsets)
+	foregroundRender = renderImageOffset(layer.scaledImage(), imageDimensions, layer.offsets)
 	if flattenedSoFar is None:
-		return foregroundRaster
-	return Image.alpha_composite(flattenedSoFar, foregroundRaster)
+		return foregroundRender
+	return Image.alpha_composite(flattenedSoFar, foregroundRender)
 
 
 def flattenAll(layers: list[LSRImageData], imageDimensions: tuple[int, int]) -> Image.Image:
@@ -232,10 +235,18 @@ def flattenAll(layers: list[LSRImageData], imageDimensions: tuple[int, int]) ->
 	return flattenedSoFar
 
 
+@deprecated(deprecated_in="2022", removed_in="2023", details="Use renderImageOffset")
 def rasterImageOffset(
 	image: Image.Image, size: tuple[int, int], offsets: tuple[int, int] = (0, 0)
 ) -> Image.Image:
-	"""Rasterise an image with offset to a given size."""
+	"""Render an image with offset to a given size. (deprecated, use renderImageOffset)"""
+	return renderImageOffset(image, size, offsets)
+
+
+def renderImageOffset(
+	image: Image.Image, size: tuple[int, int], offsets: tuple[int, int] = (0, 0)
+) -> Image.Image:
+	"""Render an image with offset to a given size."""
 	imageOffset = Image.new("RGBA", size)
 	imageOffset.paste(
 		image.convert("RGBA"), (int(offsets[0]), int(offsets[1])), image.convert("RGBA")
